<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">

<!-- Bibliogrāfiju noformēšanas stili: std, date, rus -->
<!-- std  - Standarta stils - numurēts, rietumu žurnālos -->
<!-- date - Bez numerācijas, atsaucēs (Uzvārds, gads) -->
<!-- rus  - Krievu un Latviešu tradicionālais stils. Numurēts -->
<xsl:param name="bibstyle" select="'std'"/>

<xsl:template name="form_biblioentry">
	<!-- Tagad mēģinām noteikt, kāds ir references formāts -->
	<!-- raksts žurnālā, raksts konferencē, grāmata, nespecificēts-->
	<xsl:variable name="bibformat">
		<xsl:call-template name="detect_bibformat"/>
	</xsl:variable>
	
	<!-- Sākumā uzkonstruējam bibliogrāfisko elementu koku pareizā secībā -->
	<xsl:variable name="biblioentry">
		<xsl:choose>
			<xsl:when test="$bibstyle = 'std'">
				<xsl:call-template name="form_std_biblioentry">
					<xsl:with-param name="bibformat" select="$bibformat"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$bibstyle = 'date'">
				<xsl:call-template name="form_date_biblioentry">
					<xsl:with-param name="bibformat" select="$bibformat"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$bibstyle = 'rus'">
				<xsl:call-template name="form_rus_biblioentry">
					<xsl:with-param name="bibformat" select="$bibformat"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	
	<!-- Tagad apstrādājam uzkonstruēto elementu struktūru -->
	<xsl:apply-templates select="$biblioentry" mode="biblioentry">
		<xsl:with-param name="lang" select="@lang"/>
		<xsl:with-param name="bibformat" select="$bibformat"/>
	</xsl:apply-templates>
</xsl:template>

<xsl:template name="detect_bibformat">
		<xsl:choose>
			<!-- article - Raksts -->
			<xsl:when test="(biblioset[@relation='article'] and biblioset[@relation='journal']) or (biblioset[@relation='journal'] and not(biblioset[not(@relation='journal')]))">
				<xsl:text>article</xsl:text>
			</xsl:when>
			<!-- book - Grāmata -->
			<xsl:when test="biblioset[@relation='book'] and not(biblioset[not(@relation='book')])">
				<xsl:text>book</xsl:text>
			</xsl:when>
			<!-- collection - Publicēts grāmatā / rakstu krājumā -->
			<xsl:when test="(biblioset[@relation='article'] and biblioset[@relation='collection']) or (biblioset[@relation='collection'] and not(biblioset[not(@relation='collection')]))">
				<xsl:text>collection</xsl:text>
			</xsl:when>
			<!-- proceedings - Publicēts konferences materiālos -->
			<xsl:when test="(biblioset[@relation='article'] and biblioset[@relation='proceedings']) or (biblioset[@relation='proceedings'] and not(biblioset[not(@relation='proceedings')])) or (not(biblioset) and confgroup/conftitle)">
				<xsl:text>proceedings</xsl:text>
			</xsl:when>
			<!-- masterthesis - Maģistra darbs -->
			<xsl:when test="biblioset[@relation='masterthesis'] and not(biblioset[not(@relation='masterthesis')])">
				<xsl:text>masterthesis</xsl:text>
			</xsl:when>
			<!-- phdthesis - Doktora darbs -->
			<xsl:when test="biblioset[@relation='phdthesis'] and not(biblioset[not(@relation='phdthesis')])">
				<xsl:text>phdthesis</xsl:text>
			</xsl:when>
			<!-- unspecified - Nespecificēts -->
			<xsl:otherwise>
				<xsl:text>unspecified</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
</xsl:template>

<xsl:template name="get_surname_date_citation">
	<xsl:variable name="bibformat">
		<xsl:call-template name="detect_bibformat"/>
	</xsl:variable>
	<xsl:variable name="biblioentry">
		<xsl:call-template name="form_date_biblioentry">
			<xsl:with-param name="bibformat" select="$bibformat"/>
		</xsl:call-template>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="$biblioentry/(author|editor)">
			<xsl:apply-templates select="$biblioentry/(author|editor)[1]" mode="form_surname_date_citation"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="title[1]"/>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="$biblioentry/(date|pubdate|confdates)[not(preceding-sibling::ulink)][1]">
		<xsl:text>, </xsl:text>
		<xsl:value-of select="$biblioentry/(date|pubdate|confdates)[not(preceding-sibling::ulink)][1]"/>
	</xsl:if>
</xsl:template>

<xsl:template match="author" mode="form_surname_date_citation">
	<xsl:apply-templates select="surname" mode="biblioentry"/>
	<xsl:choose>
		<xsl:when test="not(following-sibling::author)"/>
		<xsl:when test="count(preceding-sibling::author)&lt;2">
			<xsl:text>, </xsl:text>
			<xsl:apply-templates select="following-sibling::author[1]" mode="form_surname_date_citation"/>
		</xsl:when>
		<xsl:when test="count(preceding-sibling::author)=2">
			<xsl:text> ... </xsl:text>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template match="editor" mode="form_surname_date_citation">
	<xsl:apply-templates select="surname" mode="biblioentry"/>
	<xsl:choose>
		<xsl:when test="not(following-sibling::editor)">
			<xsl:text> (Ed.)</xsl:text>
		</xsl:when>
		<xsl:when test="count(preceding-sibling::editor)&lt;2">
			<xsl:text>, </xsl:text>
			<xsl:apply-templates select="following-sibling::editor[1]" mode="form_surname_date_citation"/>
		</xsl:when>
		<xsl:when test="count(preceding-sibling::editor)=2">
			<xsl:text> ... (Ed.) </xsl:text>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="form_std_biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:choose>
		<!-- Raksts žurnālā /article/ -->
		<xsl:when test="$bibformat = 'article'">
			<xsl:copy-of select="author | authorgroup/author | biblioset[@relation='article']//author"/>
			<xsl:text> </xsl:text>
			<xsl:copy-of select="title[1] | biblioset[@relation='article']/title[1]"/>
			<xsl:copy-of select="subtitle[1] | biblioset[@relation='article']/subtitle[1]"/>
			<xsl:text>. </xsl:text>
			<emphasis>
				<xsl:copy-of select="biblioset[@relation='journal']/title[1]"/>
				<xsl:copy-of select="biblioset[@relation='journal']/subtitle[1]"/>
			</emphasis>
			<xsl:text>, </xsl:text>
			<xsl:copy-of select="biblioset[@relation='journal']/volumenum[1]"/>
			
			<xsl:if test="(descendant::date and not(descendant::ulink)) or descendant::pubdate">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="descendant::pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='journal']/issuenum[1]"/>
			<xsl:copy-of select="(pagenums | biblioset[@relation='article']/pagenums)[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/issn[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="descendant::date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Grāmata /book/ -->
		<xsl:when test="$bibformat = 'book'">
			<xsl:choose>
				<xsl:when test="biblioset[@relation='book']//author">
					<xsl:copy-of select="biblioset[@relation='book']//author"/>
					<xsl:text> </xsl:text>
				</xsl:when>
				<xsl:when test="biblioset[@relation='book']/editor">
					<xsl:copy-of select="biblioset[@relation='book']/editor"/>
					<xsl:text> </xsl:text>
				</xsl:when>
			</xsl:choose>
			<emphasis>
				<xsl:copy-of select="biblioset[@relation='book']/title"/>
				<xsl:copy-of select="biblioset[@relation='book']/subtitle"/>
				<xsl:copy-of select="biblioset[@relation='book']/edition"/>
			</emphasis>
			<xsl:text> </xsl:text>
			<xsl:choose>
				<xsl:when test="biblioset[@relation='book']//publishername">
					<xsl:copy-of select="biblioset[@relation='book']//publishername[1]"/>
				</xsl:when>
				<xsl:when test="biblioset[@relation='book']/orgname">
					<xsl:copy-of select="biblioset[@relation='book']/orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="biblioset[@relation='book']//city[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']//country[1]"/>
			<xsl:if test="(biblioset[@relation='book']/date and not(biblioset[@relation='book']//ulink)) or biblioset[@relation='book']/pubdate">
				<xsl:choose>
					<xsl:when test="biblioset[@relation='book']//ulink">
						<xsl:copy-of select="biblioset[@relation='book']/pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(biblioset[@relation='book']/date | biblioset[@relation='book']/pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='book']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/issuenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/pagenums[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/issn[1]"/>
			<xsl:if test="biblioset[@relation='book']//ulink">
				<xsl:copy-of select="biblioset[@relation='book']//ulink[1]"/>
				<xsl:copy-of select="biblioset[@relation='book']/date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Rakstu krājums vai konferences materiāli /collection or proceedings/ -->
		<xsl:when test="($bibformat = 'collection') or ($bibformat = 'proceedings')">
			<xsl:if test="author | authorgroup/author | biblioset[@relation='article']//author">
				<xsl:copy-of select="author | authorgroup/author | biblioset[@relation='article']//author"/>
				<xsl:text> </xsl:text>
				<xsl:copy-of select="title[1] | biblioset[@relation='article']/title[1]"/>
				<xsl:copy-of select="subtitle[1] | biblioset[@relation='article']/subtitle[1]"/>
				<xsl:text>. </xsl:text>
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'in_proceedings'"/>
				</xsl:call-template>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:if test="editor | biblioset[@relation='collection' or @relation='proceedings']/editor">
				<xsl:copy-of select="editor | biblioset[@relation='collection' or @relation='proceedings']/editor"/>
				<xsl:text>. </xsl:text>
			</xsl:if>
			<emphasis>
				<xsl:copy-of select="(biblioset[@relation='collection' or @relation='proceedings']/title | descendant::conftitle)[1]"/>
				<xsl:copy-of select="biblioset[@relation='collection' or @relation='proceedings']/subtitle[1]"/>
			</emphasis>
			<xsl:text> </xsl:text>
			<xsl:choose>
				<xsl:when test="publishername or biblioset[@relation='collection' or @relation='proceedings']//publishername">
					<xsl:copy-of select="(publishername | biblioset[@relation='collection' or @relation='proceedings']//publishername)[1]"/>
				</xsl:when>
				<xsl:when test="orgname or biblioset[@relation='collection' or @relation='proceedings']/orgname">
					<xsl:copy-of select="(orgname | biblioset[@relation='collection' or @relation='proceedings']/orgname)[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="descendant::city[1]"/>
			<xsl:copy-of select="descendant::country[1]"/>
			<xsl:if test="(descendant::date and not(descendant::ulink)) or descendant::pubdate or descendant::confdates">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="(descendant::pubdate | descendant::confdates)[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate | descendant::confdates)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="(volumenum | biblioset[@relation='collection' or @relation='proceedings']/volumenum)[1]"/>
			<xsl:copy-of select="(issuenum | biblioset[@relation='collection' or @relation='proceedings']/issuenum)[1]"/>
			<xsl:copy-of select="(pagenums | biblioset[@relation='article']/pagenums)[1]"/>
			<xsl:copy-of select="(isbn | biblioset[@relation='collection' or @relation='proceedings']/isbn)[1]"/>
			<xsl:copy-of select="(issn | biblioset[@relation='collection' or @relation='proceedings']/issn)[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="descendant::date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Maģistra darbs vai doktora darbs /masterthesis or phdthesis/ -->
		<xsl:when test="($bibformat = 'masterthesis') or ($bibformat = 'phdthesis')">
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//author"/>
			<xsl:text> </xsl:text>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/title"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/subtitle"/>
			<xsl:text>. </xsl:text>
			<xsl:choose>
				<xsl:when test="$bibformat = 'masterthesis'">
					<xsl:call-template name="get_lang_string">
						<xsl:with-param name="lang" select="@lang"/>
						<xsl:with-param name="code" select="'masterthesis'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$bibformat = 'phdthesis'">
					<xsl:call-template name="get_lang_string">
						<xsl:with-param name="lang" select="@lang"/>
						<xsl:with-param name="code" select="'phdthesis'"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:text>, </xsl:text>
			<xsl:choose>
				<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']//publishername">
					<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//publishername[1]"/>
				</xsl:when>
				<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']/orgname">
					<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//city[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//country[1]"/>
			<xsl:if test="(biblioset[@relation='masterthesis' or @relation='phdthesis']/date and not(biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink)) or biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate">
				<xsl:choose>
					<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink">
						<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(biblioset[@relation='masterthesis' or @relation='phdthesis']/date | biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/issuenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/pagenums[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/issn[1]"/>
			<xsl:if test="biblioset[@relation='book']//ulink">
				<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink[1]"/>
				<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Ja ir nespecificēts /unspecified/ tips -->
		<xsl:otherwise>
			<xsl:if test="descendant::author">
				<xsl:copy-of select="descendant::author"/>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:copy-of select="title[1]"/>
			<xsl:copy-of select="subtitle[1]"/>
			<xsl:copy-of select="edition[1]"/>
			<xsl:text>. </xsl:text>
			<xsl:choose>
				<xsl:when test="descendant::publishername">
					<xsl:copy-of select="descendant::publishername[1]"/>
				</xsl:when>
				<xsl:when test="orgname">
					<xsl:copy-of select="orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="descendant::address/city[1]"/>
			<xsl:copy-of select="descendant::address/country[1]"/>
			<xsl:if test="(date and not(descendant::ulink)) or pubdate">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="descendant::pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="volumenum[1]"/>
			<xsl:copy-of select="issuenum[1]"/>
			<xsl:copy-of select="pagenums[1]"/>
			<xsl:copy-of select="isbn[1]"/>
			<xsl:copy-of select="issn[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="form_date_biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:choose>
		<!-- Raksts žurnālā /article/ -->
		<xsl:when test="$bibformat = 'article'">
			<xsl:copy-of select="author | authorgroup/author | biblioset[@relation='article']//author"/>
			<xsl:text> </xsl:text>
			<xsl:if test="(descendant::date and not(descendant::ulink)) or descendant::pubdate">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="descendant::pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="title[1] | biblioset[@relation='article']/title[1]"/>
			<xsl:copy-of select="subtitle[1] | biblioset[@relation='article']/subtitle[1]"/>
			<xsl:text>. </xsl:text>
			<emphasis>
				<xsl:copy-of select="biblioset[@relation='journal']/title[1]"/>
				<xsl:copy-of select="biblioset[@relation='journal']/subtitle[1]"/>
			</emphasis>
			<xsl:text>, </xsl:text>
			<xsl:copy-of select="biblioset[@relation='journal']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/issuenum[1]"/>
			<xsl:copy-of select="(pagenums | biblioset[@relation='article']/pagenums)[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/issn[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="descendant::date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Grāmata /book/ -->
		<xsl:when test="$bibformat = 'book'">
			<xsl:choose>
				<xsl:when test="biblioset[@relation='book']//author">
					<xsl:copy-of select="biblioset[@relation='book']//author"/>
					<xsl:text> </xsl:text>
				</xsl:when>
				<xsl:when test="biblioset[@relation='book']/editor">
					<xsl:copy-of select="biblioset[@relation='book']/editor"/>
					<xsl:text> </xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="(biblioset[@relation='book']/date and not(biblioset[@relation='book']//ulink)) or biblioset[@relation='book']/pubdate">
				<xsl:choose>
					<xsl:when test="biblioset[@relation='book']//ulink">
						<xsl:copy-of select="biblioset[@relation='book']/pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(biblioset[@relation='book']/date | biblioset[@relation='book']/pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<emphasis>
				<xsl:copy-of select="biblioset[@relation='book']/title"/>
				<xsl:copy-of select="biblioset[@relation='book']/subtitle"/>
				<xsl:copy-of select="biblioset[@relation='book']/edition"/>
			</emphasis>
			<xsl:text> </xsl:text>
			<xsl:choose>
				<xsl:when test="biblioset[@relation='book']//publishername">
					<xsl:copy-of select="biblioset[@relation='book']//publishername[1]"/>
				</xsl:when>
				<xsl:when test="biblioset[@relation='book']/orgname">
					<xsl:copy-of select="biblioset[@relation='book']/orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="biblioset[@relation='book']//city[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']//country[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/issuenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/pagenums[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/issn[1]"/>
			<xsl:if test="biblioset[@relation='book']//ulink">
				<xsl:copy-of select="biblioset[@relation='book']//ulink[1]"/>
				<xsl:copy-of select="biblioset[@relation='book']/date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Rakstu krājums vai konferences materiāli /collection or proceedings/ -->
		<xsl:when test="($bibformat = 'collection') or ($bibformat = 'proceedings')">
			<xsl:if test="author | authorgroup/author | biblioset[@relation='article']//author">
				<xsl:copy-of select="author | authorgroup/author | biblioset[@relation='article']//author"/>
				<xsl:text> </xsl:text>
				<xsl:if test="(descendant::date and not(descendant::ulink)) or descendant::pubdate or descendant::confdates">
					<xsl:choose>
						<xsl:when test="descendant::ulink">
							<xsl:copy-of select="(descendant::pubdate | descendant::confdates)[1]"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="(descendant::date | descendant::pubdate | descendant::confdates)[1]"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:copy-of select="title[1] | biblioset[@relation='article']/title[1]"/>
				<xsl:copy-of select="subtitle[1] | biblioset[@relation='article']/subtitle[1]"/>
				<xsl:text>. </xsl:text>
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'in_proceedings'"/>
				</xsl:call-template>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:if test="editor | biblioset[@relation='collection' or @relation='proceedings']/editor">
				<xsl:copy-of select="editor | biblioset[@relation='collection' or @relation='proceedings']/editor"/>
				<xsl:if test="not(author | authorgroup/author | biblioset[@relation='article']//author) and ((descendant::date and not(descendant::ulink)) or descendant::pubdate or descendant::confdates)">
					<xsl:text> </xsl:text>
					<xsl:choose>
						<xsl:when test="descendant::ulink">
							<xsl:copy-of select="(descendant::pubdate | descendant::confdates)[1]"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="(descendant::date | descendant::pubdate | descendant::confdates)[1]"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:text>. </xsl:text>
			</xsl:if>
			<emphasis>
				<xsl:copy-of select="(biblioset[@relation='collection' or @relation='proceedings']/title | descendant::conftitle)[1]"/>
				<xsl:copy-of select="biblioset[@relation='collection' or @relation='proceedings']/subtitle[1]"/>
			</emphasis>
			<xsl:text> </xsl:text>
			<xsl:choose>
				<xsl:when test="publishername or biblioset[@relation='collection' or @relation='proceedings']//publishername">
					<xsl:copy-of select="(publishername | biblioset[@relation='collection' or @relation='proceedings']//publishername)[1]"/>
				</xsl:when>
				<xsl:when test="orgname or biblioset[@relation='collection' or @relation='proceedings']/orgname">
					<xsl:copy-of select="(orgname | biblioset[@relation='collection' or @relation='proceedings']/orgname)[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="descendant::city[1]"/>
			<xsl:copy-of select="descendant::country[1]"/>
			<xsl:copy-of select="(volumenum | biblioset[@relation='collection' or @relation='proceedings']/volumenum)[1]"/>
			<xsl:copy-of select="(issuenum | biblioset[@relation='collection' or @relation='proceedings']/issuenum)[1]"/>
			<xsl:copy-of select="(pagenums | biblioset[@relation='article']/pagenums)[1]"/>
			<xsl:copy-of select="(isbn | biblioset[@relation='collection' or @relation='proceedings']/isbn)[1]"/>
			<xsl:copy-of select="(issn | biblioset[@relation='collection' or @relation='proceedings']/issn)[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="descendant::date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Maģistra darbs vai doktora darbs /masterthesis or phdthesis/ -->
		<xsl:when test="($bibformat = 'masterthesis') or ($bibformat = 'phdthesis')">
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//author"/>
			<xsl:text> </xsl:text>
			<xsl:if test="(biblioset[@relation='masterthesis' or @relation='phdthesis']/date and not(biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink)) or biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate">
				<xsl:choose>
					<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink">
						<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(biblioset[@relation='masterthesis' or @relation='phdthesis']/date | biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/title"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/subtitle"/>
			<xsl:text>. </xsl:text>
			<xsl:choose>
				<xsl:when test="$bibformat = 'masterthesis'">
					<xsl:call-template name="get_lang_string">
						<xsl:with-param name="lang" select="@lang"/>
						<xsl:with-param name="code" select="'masterthesis'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$bibformat = 'phdthesis'">
					<xsl:call-template name="get_lang_string">
						<xsl:with-param name="lang" select="@lang"/>
						<xsl:with-param name="code" select="'phdthesis'"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:text>, </xsl:text>
			<xsl:choose>
				<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']//publishername">
					<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//publishername[1]"/>
				</xsl:when>
				<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']/orgname">
					<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//city[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//country[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/issuenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/pagenums[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/issn[1]"/>
			<xsl:if test="biblioset[@relation='book']//ulink">
				<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink[1]"/>
				<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Ja ir nespecificēts /unspecified/ tips -->
		<xsl:otherwise>
			<xsl:if test="descendant::author">
				<xsl:copy-of select="descendant::author"/>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:if test="(date and not(descendant::ulink)) or pubdate">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="descendant::pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="title[1]"/>
			<xsl:copy-of select="subtitle[1]"/>
			<xsl:copy-of select="edition[1]"/>
			<xsl:text>. </xsl:text>
			<xsl:choose>
				<xsl:when test="descendant::publishername">
					<xsl:copy-of select="descendant::publishername[1]"/>
				</xsl:when>
				<xsl:when test="orgname">
					<xsl:copy-of select="orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:copy-of select="descendant::address/city[1]"/>
			<xsl:copy-of select="descendant::address/country[1]"/>
			<xsl:copy-of select="volumenum[1]"/>
			<xsl:copy-of select="issuenum[1]"/>
			<xsl:copy-of select="pagenums[1]"/>
			<xsl:copy-of select="isbn[1]"/>
			<xsl:copy-of select="issn[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="form_rus_biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:choose>
		<!-- Raksts /article/ -->
		<xsl:when test="$bibformat = 'article'">
			<xsl:copy-of select="author | authorgroup/author | biblioset[@relation='article']//author"/>
			<xsl:text> </xsl:text>
			<xsl:copy-of select="title[1] | biblioset[@relation='article']/title[1]"/>
			<xsl:copy-of select="subtitle[1] | biblioset[@relation='article']/subtitle[1]"/>
			<xsl:text> // </xsl:text>
			<xsl:copy-of select="biblioset[@relation='journal']/title[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/subtitle[1]"/>
			<xsl:text> — </xsl:text>
			<xsl:copy-of select="biblioset[@relation='journal']//city[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']//country[1]"/>
			<xsl:choose>
				<xsl:when test="biblioset[@relation='journal']//publishername">
					<xsl:copy-of select="biblioset[@relation='journal']//publishername[1]"/>
				</xsl:when>
				<xsl:when test="biblioset[@relation='journal']/orgname">
					<xsl:copy-of select="biblioset[@relation='journal']/orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="(descendant::date and not(descendant::ulink)) or descendant::pubdate">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="descendant::pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='journal']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/issuenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='journal']/issn[1]"/>
			<xsl:copy-of select="(pagenums | biblioset[@relation='article']/pagenums)[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="descendant::date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Grāmata /book/ -->
		<xsl:when test="$bibformat = 'book'">
			<xsl:if test="biblioset[@relation='book']//author">
				<xsl:copy-of select="biblioset[@relation='book']//author"/>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='book']/title"/>
			<xsl:copy-of select="biblioset[@relation='book']/subtitle"/>
			<xsl:copy-of select="biblioset[@relation='book']/edition"/>
			<xsl:if test="biblioset[@relation='book']/editor">
				<xsl:text> / </xsl:text>
				<xsl:copy-of select="biblioset[@relation='book']/editor"/>
			</xsl:if>
			<xsl:text> — </xsl:text>
			<xsl:copy-of select="biblioset[@relation='book']//city[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']//country[1]"/>
			<xsl:choose>
				<xsl:when test="biblioset[@relation='book']//publishername">
					<xsl:copy-of select="biblioset[@relation='book']//publishername[1]"/>
				</xsl:when>
				<xsl:when test="biblioset[@relation='book']/orgrname">
					<xsl:copy-of select="biblioset[@relation='book']/orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="(biblioset[@relation='book']/date and not(biblioset[@relation='book']//ulink)) or biblioset[@relation='book']/pubdate">
				<xsl:choose>
					<xsl:when test="biblioset[@relation='book']//ulink">
						<xsl:copy-of select="biblioset[@relation='book']/pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(biblioset[@relation='book']/date | biblioset[@relation='book']/pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='book']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/issuenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/pagenums[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='book']/issn[1]"/>
			<xsl:if test="biblioset[@relation='book']//ulink">
				<xsl:copy-of select="biblioset[@relation='book']//ulink[1]"/>
				<xsl:copy-of select="biblioset[@relation='book']/date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Rakstu krājums vai konferences materiāli /collection or proceedings/ -->
		<xsl:when test="($bibformat = 'collection') or ($bibformat = 'proceedings')">
			<xsl:if test="author | authorgroup/author | biblioset[@relation='article']//author">
				<xsl:copy-of select="author | authorgroup/author | biblioset[@relation='article']//author"/>
				<xsl:text> </xsl:text>
				<xsl:copy-of select="title[1] | biblioset[@relation='article']/title[1]"/>
				<xsl:copy-of select="subtitle[1] | biblioset[@relation='article']/subtitle[1]"/>
				<xsl:text> // </xsl:text>
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'in_proceedings'"/>
				</xsl:call-template>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:copy-of select="(biblioset[@relation='collection' or @relation='proceedings']/title | descendant::conftitle)[1]"/>
			<xsl:copy-of select="biblioset[@relation='collection' or @relation='proceedings']/subtitle[1]"/>
			<xsl:copy-of select="edition | biblioset[@relation='collection' or @relation='proceedings']/edition"/>
			<xsl:if test="editor or biblioset[@relation='collection' or @relation='proceedings']/editor">
				<xsl:text> / </xsl:text>
				<xsl:copy-of select="editor | biblioset[@relation='collection' or @relation='proceedings']/editor"/>
			</xsl:if>
			<xsl:text> — </xsl:text>
			<xsl:copy-of select="descendant::city[1]"/>
			<xsl:copy-of select="descendant::country[1]"/>
			<xsl:choose>
				<xsl:when test="publishername or biblioset[@relation='collection' or @relation='proceedings']//publishername">
					<xsl:copy-of select="(publishername | biblioset[@relation='collection' or @relation='proceedings']//publishername)[1]"/>
				</xsl:when>
				<xsl:when test="orgname or biblioset[@relation='collection' or @relation='proceedings']/orgname">
					<xsl:copy-of select="(orgname | biblioset[@relation='collection' or @relation='proceedings']/orgname)[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="(descendant::date and not(descendant::ulink)) or descendant::pubdate or descendant::confdates">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="(descendant::pubdate | descendant::confdates)[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate | descendant::confdates)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="(volumenum | biblioset[@relation='collection' or @relation='proceedings']/volumenum)[1]"/>
			<xsl:copy-of select="(issuenum | biblioset[@relation='collection' or @relation='proceedings']/issuenum)[1]"/>
			<xsl:copy-of select="(pagenums | biblioset[@relation='article']/pagenums)[1]"/>
			<xsl:copy-of select="(isbn | biblioset[@relation='collection' or @relation='proceedings']/isbn)[1]"/>
			<xsl:copy-of select="(issn | biblioset[@relation='collection' or @relation='proceedings']/issn)[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="descendant::date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Maģistra darbs vai doktora darbs /masterthesis or phdthesis/ -->
		<xsl:when test="($bibformat = 'masterthesis') or ($bibformat = 'phdthesis')">
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//author"/>
			<xsl:text> </xsl:text>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/title"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/subtitle"/>
			<xsl:text>. </xsl:text>
			<xsl:choose>
				<xsl:when test="$bibformat = 'masterthesis'">
					<xsl:call-template name="get_lang_string">
						<xsl:with-param name="lang" select="@lang"/>
						<xsl:with-param name="code" select="'masterthesis'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$bibformat = 'phdthesis'">
					<xsl:call-template name="get_lang_string">
						<xsl:with-param name="lang" select="@lang"/>
						<xsl:with-param name="code" select="'phdthesis'"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:text> — </xsl:text>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//city[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//country[1]"/>
			<xsl:choose>
				<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']//publishername">
					<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//publishername[1]"/>
				</xsl:when>
				<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']/orgrname">
					<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="(biblioset[@relation='masterthesis' or @relation='phdthesis']/date and not(biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink)) or biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate">
				<xsl:choose>
					<xsl:when test="biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink">
						<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(biblioset[@relation='masterthesis' or @relation='phdthesis']/date | biblioset[@relation='masterthesis' or @relation='phdthesis']/pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/volumenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/issuenum[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/pagenums[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/isbn[1]"/>
			<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/issn[1]"/>
			<xsl:if test="biblioset[@relation='book']//ulink">
				<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']//ulink[1]"/>
				<xsl:copy-of select="biblioset[@relation='masterthesis' or @relation='phdthesis']/date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:when>

		<!-- Ja ir nespecificēts /unspecified/ tips -->
		<xsl:otherwise>
			<xsl:if test="descendant::author">
				<xsl:copy-of select="descendant::author"/>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:copy-of select="title[1]"/>
			<xsl:copy-of select="subtitle[1]"/>
			<xsl:copy-of select="edition[1]"/>
			<xsl:text> — </xsl:text>
			<xsl:copy-of select="descendant::address/city[1]"/>
			<xsl:copy-of select="descendant::address/country[1]"/>
			<xsl:copy-of select="descendant::conftitle[1]"/>
			<xsl:choose>
				<xsl:when test="descendant::publishername">
					<xsl:copy-of select="descendant::publishername[1]"/>
				</xsl:when>
				<xsl:when test="orgname">
					<xsl:copy-of select="orgname[1]"/>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="(date and not(descendant::ulink)) or pubdate">
				<xsl:choose>
					<xsl:when test="descendant::ulink">
						<xsl:copy-of select="descendant::pubdate[1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="(descendant::date | descendant::pubdate)[1]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:copy-of select="volumenum[1]"/>
			<xsl:copy-of select="issuenum[1]"/>
			<xsl:copy-of select="pagenums[1]"/>
			<xsl:copy-of select="isbn[1]"/>
			<xsl:copy-of select="issn[1]"/>
			<xsl:if test="descendant::ulink">
				<xsl:copy-of select="descendant::ulink[1]"/>
				<xsl:copy-of select="date[1]"/>
			</xsl:if>
			<xsl:text>.</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- =============================================================== -->
<!-- Atsevišķo bibliogrāfijas elementu apstrāde -->

<xsl:template match="author" mode="biblioentry">
	<xsl:apply-templates select="surname" mode="biblioentry"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="firstname" mode="biblioentry"/>
	<xsl:apply-templates select="othername" mode="biblioentry"/>
	<xsl:if test="following-sibling::author">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="editor" mode="biblioentry">
	<xsl:param name="lang"/>
	<xsl:apply-templates select="surname" mode="biblioentry"/>
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="firstname" mode="biblioentry"/>
	<xsl:apply-templates select="othername" mode="biblioentry"/>
	<xsl:choose>
		<xsl:when test="following-sibling::editor[2]">
			<xsl:text>, </xsl:text>
		</xsl:when>
		<xsl:when test="following-sibling::editor">
			<xsl:text> </xsl:text>
			<xsl:call-template name="get_lang_string">
				<xsl:with-param name="lang" select="$lang"/>
				<xsl:with-param name="code" select="'and'"/>
			</xsl:call-template>
			<xsl:text> </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text> (</xsl:text>
			<xsl:call-template name="get_lang_string">
				<xsl:with-param name="lang" select="$lang"/>
				<xsl:with-param name="code" select="'editor'"/>
			</xsl:call-template>
			<xsl:text>)</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="surname" mode="biblioentry">
	<xsl:apply-templates/>
</xsl:template>
<xsl:template match="firstname | othername" mode="biblioentry">
	<xsl:value-of select="substring(text(),1,1)"/>
	<xsl:text>.</xsl:text>
</xsl:template>

<xsl:template match="title" mode="biblioentry">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="subtitle" mode="biblioentry">
	<xsl:text>. </xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="edition" mode="biblioentry">
	<xsl:param name="lang"/>
	<xsl:text>. </xsl:text>
	<xsl:call-template name="get_lang_string">
		<xsl:with-param name="lang" select="$lang"/>
		<xsl:with-param name="code" select="'edition'"/>
		<xsl:with-param name="value"><xsl:apply-templates/></xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template match="city" mode="biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings') and not(preceding-sibling::publishername or preceding-sibling::orgname)">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings') and not(following-sibling::country or following-sibling::date or following-sibling::pubdate)">
		<xsl:text>)</xsl:text>
	</xsl:if>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="country" mode="biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings') and not(preceding-sibling::publishername or preceding-sibling::orgname or preceding-sibling::city)">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings') and not(following-sibling::date or following-sibling::pubdate)">
		<xsl:text>)</xsl:text>
	</xsl:if>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="publishername" mode="biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings')">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings') and not(following-sibling::city or following-sibling::country or following-sibling::date or following-sibling::pubdate)">
		<xsl:text>)</xsl:text>
	</xsl:if>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="orgname" mode="biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings')">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:if test="($bibstyle='std' or $bibstyle='date') and ($bibformat='book' or $bibformat='collecion' or $bibformat='proceedings') and not(following-sibling::city or following-sibling::country or following-sibling::date or following-sibling::pubdate)">
		<xsl:text>)</xsl:text>
	</xsl:if>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="conftitle" mode="biblioentry">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="date" mode="biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:if test="$bibstyle='std' and $bibformat='article' and not(preceding-sibling::ulink or preceding-sibling::publishername or preceding-sibling::orgname or preceding-sibling::city or preceding-sibling::country)">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:if test="$bibstyle='date' and not(preceding-sibling::ulink)">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:if test="$bibstyle='std' and ($bibformat='article' or $bibformat='book' or $bibformat='collecion' or $bibformat='proceedings') and not(preceding-sibling::ulink)">
		<xsl:text>)</xsl:text>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="$bibstyle='date' and not(preceding-sibling::ulink)">
			<xsl:text>). </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test="following-sibling::*">
				<xsl:text>, </xsl:text>
			</xsl:if>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="pubdate" mode="biblioentry">
	<xsl:param name="bibformat"/>
	<xsl:if test="$bibstyle='std' and $bibformat='article' and not(preceding-sibling::publishername or preceding-sibling::orgname or preceding-sibling::city or preceding-sibling::country)">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:if test="$bibstyle='date'">
		<xsl:text>(</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
	<xsl:if test="$bibstyle='std' and ($bibformat='article' or $bibformat='book' or $bibformat='collecion' or $bibformat='proceedings')">
		<xsl:text>)</xsl:text>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="$bibstyle='date'">
			<xsl:text>). </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test="following-sibling::*">
				<xsl:text>, </xsl:text>
			</xsl:if>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="confdates" mode="biblioentry">
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="volumenum" mode="biblioentry">
	<xsl:param name="lang"/>
	<xsl:param name="bibformat"/>
	<xsl:call-template name="get_lang_string">
		<xsl:with-param name="lang" select="$lang"/>
		<xsl:with-param name="code" select="'volumenum'"/>
		<xsl:with-param name="value"><xsl:apply-templates/></xsl:with-param>
	</xsl:call-template>
	<xsl:choose>
		<xsl:when test="$bibstyle='std' and $bibformat='article' and (following-sibling::date | following-sibling::pubdate)">
			<xsl:text> </xsl:text>
		</xsl:when>
		<xsl:when test="following-sibling::*">
			<xsl:text>, </xsl:text>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template match="issuenum" mode="biblioentry">
	<xsl:param name="lang"/>
	<xsl:call-template name="get_lang_string">
		<xsl:with-param name="lang" select="$lang"/>
		<xsl:with-param name="code" select="'issuenum'"/>
		<xsl:with-param name="value"><xsl:apply-templates/></xsl:with-param>
	</xsl:call-template>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="pagenums" mode="biblioentry">
	<xsl:param name="lang"/>
	<xsl:call-template name="get_lang_string">
		<xsl:with-param name="lang" select="$lang"/>
		<xsl:with-param name="code" select="'pagenums'"/>
		<xsl:with-param name="value"><xsl:apply-templates/></xsl:with-param>
	</xsl:call-template>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="isbn" mode="biblioentry">
	<xsl:text>ISBN: </xsl:text>
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="issn" mode="biblioentry">
	<xsl:text>ISSN: </xsl:text>
	<xsl:apply-templates/>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="ulink" mode="biblioentry">
	<xsl:apply-templates select="."/>
	<xsl:if test="following-sibling::*">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

</xsl:stylesheet>

